********************************************************************************
************** WB Investment projects and absorptive capacity ******************
********************************************************************************

***                     Author: Andrea Presbitero - IMF                      ***
***                        This version: Nov 20, 2015                        ***

** SELECT WORKING DIRECTORIES **
global output  "/OUTPUT"
set matsize 11000

***************************************************************************
***                        DESCRIPTIVE ANALYSIS                         ***
***************************************************************************
use JDE_data, clear

xi: ivreg2 outcome project_size wb_sh share_sector ///
	ERR repeat  i.LI i.timesectorWB i.timesectorWB2 if InvLoan==1, rob
distinct wbcode if e(sample)
keep if e(sample)
count
ta sectorWB
sum outcome
gen number = 1
bysort ApprovalFY wbcode: egen count_c = seq()
replace count_c = . if count_c!=1
preserve
collapse (mean) outcome (sum) number count_c, by(ApprovalFY)

/* Figure 1 */
twoway (bar number    ApprovalFY, yaxis(1) lcol(emidblue) fcolor(ebg) barwidth(.75)) ///
	   (bar count_c   ApprovalFY, yaxis(1) lcol(dknavy) fcolor(edkblue) barwidth(.5))  ///	
	   (line outcome  ApprovalFY, yaxis(2)  ///	
		ylabel(0(50)300, angle(0) labsize(small) axis(1)) ylabel(.2(.1).9, angle(0) labsize(small) axis(2))  ///
		ytitle("Number of countries/projects", size(medsmall) axis(1)) ///
		ytitle("Share of successful projects", size(medsmall) axis(2)) ///
		xlabel(1970(3)2007, labsize(small)) ///
		lp(solid) lwidth(medthick) lcolor(cranberry) ///
		xtitle("", size(medsmall)) graphregion(color(white)) ///
		legend(lab(1 "Number of projects") lab(2 "Number of countries") lab(3 "Share of successful projects") lab(4 "Share of successful projects (restrictive)") ///
		size(small) row(2) bexpand region(lstyle(none) fcolor(none)) span))  
graph export "$output/projects_Ayear.pdf", as(pdf) replace  

sum outcome
sum outcome if ApprovalFY>1979 & ApprovalFY<1990
sum outcome if ApprovalFY>1990

restore
global project "project_size wb_sh share_sector ERR repeat i.LI"  
global macro "SCALEUP gdppcgrowth_in CPIA_in lgdp_in hc_mean oda2gni_mean HI_mean"

xi: reghdfe outcome $macro $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
distinct wbcode if e(sample)
su outcome if e(sample)
ta sectorWB if e(sample)
ta CtryName if e(sample)

/* Table 1 */
sum outcome project_size wb_sh share_sector ERR repeat length time_eval INFRA ///
	SCALEUP scaleup3_mean scaleup10_mean scaleup3_in scaleup5_in scaleup10_in BOOM BOOM2 ///
	gdppcgrowth_in CPIA_in lgdp_in hc_mean oda2gni_mean oda2gni_in HI_mean HI_in CR3_mean GY_in deltaG IDA_IBRD_mean resource_mean ///
	 if e(sample), sep(100)

	
xi: reg outcome $macro $project if InvLoan==1
distinct wbcode if e(sample)

cap drop SAMPLE
gen SAMPLE = 1 if e(sample)
 
count
collapse (mean) outcome , by(wbcode CtryName)
replace wbcode = "ROM" if wbcode=="ROU"
replace wbcode = "ZAR" if wbcode=="COD"
rename wbcode wb_a3
count
sort wb_a3
merge 1:m wb_a3 using worlddata
*keep if _m==3
drop _m
format %9.2g outcome

/* Figure 2 */
spmap outcome using "worldcoor.dta", id(id) fcolor(Blues2) clmethod(quantile) clnumber(5)  ocolor(black ..) osize(thin ..) ///
	title("Share of successful projects by country (1970-2007)", size(medsmall)) ///
	legend(on) legstyle(1) legtitle(Quintiles) legend(ring(0) position(9) size(small)) legorder(lohi) 
graph export "$output/map_projects.pdf", as(pdf) replace  



***************************************************************************
***                         EMPIRICAL ANALYSIS                          ***
***************************************************************************
use JDE_data, clear

** Table 2 - baseline **
global project "project_size wb_sh share_sector ERR repeat i.LI"  
global macro "SCALEUP gdppcgrowth_in CPIA_in lgdp_in hc_mean oda2gni_mean HI_mean" 

xi: reghdfe outcome $macro $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
gen sample = 1 if e(sample)

xi: reghdfe outcome $project if sample==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
outreg2 using "JDErev_baseline.xls", replace ctitle(1) drop(_It* _Is*)  ///
			 addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

xi: reghdfe outcome $project if sample==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2 ccode) dropsin nocons vce(cl ccode#EvalFY)
outreg2 using "JDErev_baseline.xls", append ctitle(2) drop(_It* _Is* _Ic*)  ///
			 addtext(Country FE, YES, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

xi: reghdfe outcome $macro $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
outreg2 using "JDErev_baseline.xls", append ctitle(3) drop(_It* _Is* _Ic*)  ///
			 addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

xi: reghdfe outcome $macro $project if InvLoan==1 & INFRA==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
outreg2 using "JDErev_baseline.xls", append ctitle(3) drop(_It* _Is* _Ic*)  ///
			 addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

xi: reghdfe outcome $macro $project if InvLoan==1 & EvalFY>=1995, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
outreg2 using "JDErev_baseline.xls", append ctitle(3) drop(_It* _Is* _Ic*)  ///
			 addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

			 
** Placebo test - simply for the annex (Table A3) **
global project "project_size share_sector repeat i.LI"
xi: reghdfe outcome $macro $project if InvLoan==0, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
outreg2 using "JDErev_placebo.xls", replace ctitle(DPLs) drop(_It* _Is*)  ///
			 addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

/* Table 3:  test for absorptive capacity */
global project "project_size wb_sh share_sector ERR repeat i.LI"  

xi: reghdfe outcome $macro $project if InvLoan==1 & ac==0, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
outreg2 using "JDErev_abs.xls", replace ctitle(Constrained) drop(_It* _Is*)  ///
			 addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

xi: reghdfe outcome $macro $project if InvLoan==1 & ac==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
outreg2 using "JDErev_abs.xls", append ctitle(Unconstrained) drop(_It* _Is*)  ///
			 addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)


/* Table 4: heterogeneities */ 
		cap drop inter*
		gen inter1 = SCALEUP*(GY_mean)
		gen inter2 = SCALEUP*CPIA_in
		gen inter3 = SCALEUP*lgdp_in
		gen inter4 = SCALEUP*oda2gni_mean
		gen inter4b = SCALEUP*resource_mean
		gen inter5 = SCALEUP*HI_mean
		gen inter6 = SCALEUP*SCALEUP

qui xi: reghdfe outcome $macro $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_inter.xls", replace ctitle(1) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)
	
qui xi: reghdfe outcome inter1 GY_in $macro $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_inter.xls", append ctitle(GY) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome inter2 $macro $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_inter.xls", append ctitle(CPIA) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome inter3 $macro $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_inter.xls", append ctitle(GDP) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome inter1 inter2 inter3 GY_in $macro $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
    outreg2  using "JDErev_inter.xls", append ctitle(ALL) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome inter4 $macro $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_inter.xls", append ctitle(AID) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome inter5 $macro $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_inter.xls", append ctitle(FRAG) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome inter6 $macro $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_inter.xls", append ctitle(SQUARED) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)


/* Table 5 - Country FE: Regressions with project lavel variables and macro controls, baseline & subsamples */

qui xi: reghdfe outcome $macro $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2 ccode) dropsin nocons vce(cl ccode#EvalFY)
outreg2 using "JDErev_FE.xls", replace ctitle(ALL) drop(_It* _Is* _Iw* _IL*)  ///
		addtext(Country FE, YES, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome $macro $project if InvLoan==1 & INFRA==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2 ccode) dropsin nocons vce(cl ccode#EvalFY)
outreg2 using "JDErev_FE.xls", append ctitle(Infra Proj) drop(_It* _Is* _Iw* _IL*)  ///
		addtext(Country FE, YES, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome $macro $project if InvLoan==1 & EvalFY>=1995, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2 ccode) dropsin nocons vce(cl ccode#EvalFY)
outreg2 using "JDErev_FE.xls", append ctitle(Post95) drop(_It* _Is* _Iw* _IL*)  ///
		addtext(Country FE, YES, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome $macro $project if InvLoan==1 & ac==0, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2 ccode) dropsin nocons vce(cl ccode#EvalFY)
outreg2 using "JDErev_FE.xls", append ctitle(Constrained) drop(_It* _Is* _Iw* _IL*)  ///
		addtext(Country FE, YES, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome $macro $project if InvLoan==1 & ac==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2 ccode) dropsin nocons vce(cl ccode#EvalFY)
outreg2 using "JDErev_FE.xls", append ctitle(Unconstrained) drop(_It* _Is* _Iw* _IL*)  ///
		addtext(Country FE, YES, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

	 
** Table 7: Robustness using alternative definition of SCALEUP
global macro "gdppcgrowth_in CPIA_in lgdp_in hc_mean oda2gni_mean HI_mean"

qui xi: reghdfe outcome SCALEUP $macro $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
cap drop sample 
gen sample = 1 if e(sample)
qui outreg2  using "JDErev_alt.xls", replace ctitle(0) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome scaleup3_mean $macro $project if sample==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_alt.xls", append ctitle(1) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome scaleup10_mean $macro $project if sample==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_alt.xls", append ctitle(1) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome scaleup3_in $macro $project if sample==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_alt.xls", append ctitle(1) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome scaleup5_in $macro $project if sample==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_alt.xls", append ctitle(1) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome scaleup10_in $macro $project if sample==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_alt.xls", append ctitle(1) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome deltaG $macro $project if sample==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_alt.xls", append ctitle(1) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome BOOM $macro $project if sample==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_alt.xls", append ctitle(1) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome BOOM2 $macro $project if sample==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
    outreg2  using "JDErev_alt.xls", append ctitle(1) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)


				
/* Table 6 - Addition controls at the project and macro level -- added natural resources */		 
global macro "SCALEUP gdppcgrowth_in CPIA_in lgdp_in hc_mean oda2gni_mean HI_mean"
qui xi: reghdfe outcome $macro $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
cap drop sample 
gen sample = 1 if e(sample)

global macro "SCALEUP gdppcgrowth_in CPIA_in lgdp_in hc_mean"
qui xi: reghdfe outcome $macro oda2gni_mean HI_mean $project length i.type time_eval if sample==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_controls.xls", replace ctitle(1) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Type evaluation FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome $macro oda2gni_mean HI_mean GY_mean $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_controls.xls", append ctitle(1) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, NO, Type evaluation FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome $macro oda2gni_in HI_in $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_controls.xls", append ctitle(1) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, NO, Type evaluation FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome $macro oda2gni_mean CR3_mean $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_controls.xls", append ctitle(1) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, NO, Type evaluation FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome $macro IDA_IBRD_mean HI_mean $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
qui outreg2  using "JDErev_controls.xls", append ctitle(1) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, NO, Type evaluation FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: reghdfe outcome $macro oda2gni_mean HI_mean resource_mean $project if InvLoan==1, a(ApprovalFY#sectorWB2 EvalFY#sectorWB2) dropsin nocons vce(cl ccode#EvalFY)
    outreg2  using "JDErev_controls.xls", append ctitle(1) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, NO, Type evaluation FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)


** ANNEX TABLES - PROBIT ESTIMATES **

/* Table A4: Probit regressions with project lavel variables and macro controls, baseline & subsamples */
local cluster "wbcode EvalFY"

global macro "SCALEUP gdppcgrowth_in CPIA_in lgdp_in hc_mean oda2gni_mean HI_mean"
qui xi: probit outcome $macro $project i.timesectorWB i.timesectorWB2 if InvLoan==1, cluster(`cluster') 

qui xi: probit outcome $project i.timesectorWB i.timesectorWB2 if e(sample)==1, cluster(`cluster') 
outreg2 using "JDErev_probit.xls", replace ctitle(ALL) drop(_It* _Is*)  ///
			 addtext(Country FE, NO, Sector FE, YES, Year FE, NO, Year*Sector FE, YES) dec(3) sdec(3)
	
qui xi: probit outcome $project i.timesectorWB i.timesectorWB2 i.wbcode if e(sample)==1, cluster(`cluster') 
outreg2 using "JDErev_probit.xls", append ctitle(ALL) drop(_It* _Is* _Iw*)  ///
			 addtext(Country FE, YES, Sector FE, YES, Year FE, NO, Year*Sector FE, YES) dec(3) sdec(3)
	
qui xi: probit outcome $macro $project i.timesectorWB i.timesectorWB2 if e(sample)==1, cluster(`cluster') 
outreg2 using "JDErev_probit.xls", append ctitle(ALL) drop(_It* _Is*)  ///
			 addtext(Country FE, NO, Sector FE, YES, Year FE, NO, Year*Sector FE, YES) dec(3) sdec(3)

qui xi: probit outcome $macro $project i.timesectorWB i.timesectorWB2 if InvLoan==1 & INFRA==1, cluster(`cluster') 
outreg2 using "JDErev_probit.xls", append ctitle(Infra projects) drop(_It* _Is*)  ///
			 addtext(Country FE, NO, Sector FE, YES, Year FE, NO, Year*Sector FE, YES) dec(3) sdec(3)

qui xi: probit outcome $macro $project i.timesectorWB i.timesectorWB2 if InvLoan==1 & EvalFY>=1995, cluster(`cluster') 
outreg2 using "JDErev_probit.xls", append ctitle(post1995) drop(_It* _Is*)  ///
			 addtext(Country FE, NO, Sector FE, YES, Year FE, NO, Year*Sector FE, YES) dec(3) sdec(3)

/* Table A5: test for absorptive capacity - probit */
global macro "SCALEUP gdppcgrowth_in CPIA_in lgdp_in hc_mean oda2gni_mean HI_mean"
global project "project_size wb_sh share_sector ERR repeat i.LI"  

xi: probit outcome $macro $project i.timesectorWB i.timesectorWB2 if InvLoan==1 & ac==0, cluster(`cluster')
outreg2 using "JDErev_abs_probit.xls", replace ctitle(Constrained) drop(_It* _Is*)  ///
			 addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

xi: probit outcome $macro $project i.timesectorWB i.timesectorWB2 if InvLoan==1 & ac==1, cluster(`cluster')
outreg2 using "JDErev_abs_probit.xls", append ctitle(Unconstrained) drop(_It* _Is*)  ///
			 addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

			 
/* Table A6: test for heterogeneity - probit */
		cap drop inter*
		gen inter1 = SCALEUP*(GY_mean)
		gen inter2 = SCALEUP*CPIA_in
		gen inter3 = SCALEUP*lgdp_in
		gen inter4 = SCALEUP*oda2gni_mean
		gen inter5 = SCALEUP*HI_mean
		gen inter6 = SCALEUP*SCALEUP
		
qui xi: probit outcome $macro $project i.timesectorWB i.timesectorWB2 if InvLoan==1, cluster(`cluster')
qui outreg2  using "JDErev_inter_probit.xls", replace ctitle(1) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)
	
qui xi: probit outcome inter1 GY_in $macro $project i.timesectorWB i.timesectorWB2 if InvLoan==1, cluster(`cluster')
qui outreg2  using "JDErev_inter_probit.xls", append ctitle(GY) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: probit outcome inter2 $macro $project i.timesectorWB i.timesectorWB2 if InvLoan==1, cluster(`cluster')
qui outreg2  using "JDErev_inter_probit.xls", append ctitle(CPIA) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: probit outcome inter3 $macro $project i.timesectorWB i.timesectorWB2 if InvLoan==1, cluster(`cluster')
qui outreg2  using "JDErev_inter_probit.xls", append ctitle(GDP) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: probit outcome inter1 inter2 inter3 GY_in $macro $project i.timesectorWB i.timesectorWB2 if InvLoan==1, cluster(`cluster')
    outreg2  using "JDErev_inter_probit.xls", append ctitle(ALL) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: probit outcome inter4 $macro $project i.timesectorWB i.timesectorWB2 if InvLoan==1, cluster(`cluster')
qui outreg2  using "JDErev_inter_probit.xls", append ctitle(AID) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: probit outcome inter5 $macro $project i.timesectorWB i.timesectorWB2 if InvLoan==1, cluster(`cluster')
qui outreg2  using "JDErev_inter_probit.xls", append ctitle(FRAG) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

qui xi: probit outcome inter6 $macro $project i.timesectorWB i.timesectorWB2 if InvLoan==1, cluster(`cluster')
qui outreg2  using "JDErev_inter_probit.xls", append ctitle(SQUARED) drop(_It* _Is* _IL*) ///
		addtext(Country FE, NO, Lending instruments FE, YES, Approval year * Sector FE, YES, Evaluation year * Sector FE, YES) dec(3) sdec(3)

		
** STOP **
